summaryrefslogtreecommitdiffstats
path: root/kalzium/src/molcalcwidget.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:44:41 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:44:41 +0000
commita374efce3a207b39514be3c52264091400ce297e (patch)
tree77bdf654b55826d4f59b53a5621310206bcaead1 /kalzium/src/molcalcwidget.h
parentf81a494f3957d5cf38c787973415597941934727 (diff)
downloadtdeedu-a374efce3a207b39514be3c52264091400ce297e.tar.gz
tdeedu-a374efce3a207b39514be3c52264091400ce297e.zip
TQt4 port kdeedu
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1236073 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kalzium/src/molcalcwidget.h')
-rw-r--r--kalzium/src/molcalcwidget.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kalzium/src/molcalcwidget.h b/kalzium/src/molcalcwidget.h
index c86d41d3..27cb0269 100644
--- a/kalzium/src/molcalcwidget.h
+++ b/kalzium/src/molcalcwidget.h
@@ -41,13 +41,14 @@ class MoleculeParser;
class MolcalcWidget : public MolcalcWidgetBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor
* @param parent parent widget
* @param name name of this widget
*/
- MolcalcWidget( TQWidget *parent = 0, const char *name = 0 );
+ MolcalcWidget( TQWidget *tqparent = 0, const char *name = 0 );
protected slots:
void slotCalcButtonClicked();
@@ -41,13 +41,14 @@ class MoleculeParser;
/**
* Constructor
- * @param parent parent widget
+ * @param tqparent tqparent widget
* @param name name of this widget
*/